@@ -26,7 +26,8 @@ def descend_tree(search_path,file_type_list,variable_list,experiment_list,diag_t
 
 def experiment_variable_search(session,file_expt,search_path,file_type_list,experiment,var_name,frequency,realm,mip):
 
-    conn = SearchConnection(search_path, distrib=False)
+    #conn = SearchConnection(search_path, distrib=False)
+    conn = SearchConnection(search_path, distrib=True)
 
     #Search the ESGF:
     ctx = conn.new_context()
